use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Rolle::Table)
                    .if_not_exists()
                    .col(ColumnDef::new(Rolle::Id).uuid().not_null().primary_key())
                    .col(ColumnDef::new(Rolle::Name).string().not_null())
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Rolle::Table).to_owned())
            .await
    }
}

#[derive(Iden)]
#[iden(rename = "rollen")]
pub enum Rolle {
    Table,
    Id,
    Name,
}
