use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Benutzer::Table)
                    .if_not_exists()
                    .col(ColumnDef::new(Benutzer::Id).uuid().not_null().primary_key())
                    .col(ColumnDef::new(Benutzer::Nachname).string().not_null())
                    .col(ColumnDef::new(Benutzer::Vorname).string().not_null())
                    .col(ColumnDef::new(Benutzer::Kennung).string().not_null())
                    .col(ColumnDef::new(Benutzer::EMail).string().not_null())
                    .col(ColumnDef::new(Benutzer::Telefon).string().not_null())
                    .col(ColumnDef::new(Benutzer::RolleId).integer())
                    .col(ColumnDef::new(Benutzer::GruppenId).integer())
                    .col(ColumnDef::new(Benutzer::DienststelleId).integer())
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Benutzer::Table).to_owned())
            .await
    }
}

#[derive(Iden)]
#[iden(rename = "benutzer")]
enum Benutzer {
    Table,
    Id,
    Nachname,
    Vorname,
    Kennung,
    EMail,
    Telefon,
    RolleId,
    GruppenId,
    DienststelleId,
}
