use sea_orm_migration::prelude::*;

use crate::{m20240618_151728_create_gruppe::Gruppe, m20240618_151732_create_rolle::Rolle};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(RolleGruppe::Table)
                    .if_not_exists()
                    .primary_key(
                        Index::create()
                            .table(RolleGruppe::Table)
                            .col(RolleGruppe::RolleId)
                            .col(RolleGruppe::GruppeId),
                    )
                    .col(ColumnDef::new(RolleGruppe::RolleId).uuid().not_null())
                    .col(ColumnDef::new(RolleGruppe::GruppeId).uuid().not_null())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk_rolle")
                            .from(RolleGruppe::Table, RolleGruppe::RolleId)
                            .to(Rolle::Table, Rolle::Id)
                            .on_delete(ForeignKeyAction::Cascade)
                            .on_update(ForeignKeyAction::Cascade),
                    )
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk_gruppe")
                            .from(RolleGruppe::Table, RolleGruppe::GruppeId)
                            .to(Gruppe::Table, Gruppe::Id)
                            .on_update(ForeignKeyAction::Cascade)
                            .on_delete(ForeignKeyAction::Cascade),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(RolleGruppe::Table).to_owned())
            .await
    }
}

#[derive(Iden)]
#[iden(rename = "rollen_gruppen")]
enum RolleGruppe {
    Table,
    RolleId,
    GruppeId,
}
